summaryrefslogtreecommitdiffstats
path: root/kdecore/network/kresolver.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdecore/network/kresolver.h')
-rw-r--r--kdecore/network/kresolver.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/kdecore/network/kresolver.h b/kdecore/network/kresolver.h
index 5b66f362c..069428904 100644
--- a/kdecore/network/kresolver.h
+++ b/kdecore/network/kresolver.h
@@ -101,7 +101,7 @@ public:
* @param canonName the canonical name of the resolved hostname
* @param encodedName the ASCII-compatible encoding of the hostname
*/
- KResolverEntry(const struct sockaddr *sa, Q_UINT16 salen, int socktype,
+ KResolverEntry(const struct sockaddr *sa, TQ_UINT16 salen, int socktype,
int protocol, const TQString& canonName = TQString::null,
const TQCString& encodedName = TQCString());
@@ -128,7 +128,7 @@ public:
/**
* Retrieves the length of the socket address structure.
*/
- Q_UINT16 length() const;
+ TQ_UINT16 length() const;
/**
* Retrieves the family associated with this socket address.
@@ -292,9 +292,10 @@ class KResolverPrivate;
*
* @author Thiago Macieira <thiago.macieira@kdemail.net>
*/
-class KDECORE_EXPORT KResolver: public QObject
+class KDECORE_EXPORT KResolver: public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -795,11 +796,11 @@ public:
* Note that the encoding is illegible and, thus, should not be presented
* to the user, except if requested.
*
* @param unicodeDomain the domain name to be encoded
* @return the ACE-encoded suitable for DNS queries if successful, a null
* TQCString if failure.
*/
- static TQCString domainToAscii(const TQString& unicodeDomain);
+ static TQCString domainToAscii(const TQString& tqunicodeDomain);
/**
* Does the inverse of @ref domainToAscii and return an Unicode domain
@@ -795,11 +796,11 @@ public:
* to the user, except if requested.
*
- * @param unicodeDomain the domain name to be encoded
+ * @param tqunicodeDomain the domain name to be encoded
* @return the ACE-encoded suitable for DNS queries if successful, a null
* TQCString if failure.